pub struct Copper;Expand description
Friendly black to brown colormap.
Implementations
Sourceimpl Copper
impl Copper
Sourcepub fn get_color<FloatType>(h: FloatType) -> RGBColor
pub fn get_color<FloatType>(h: FloatType) -> RGBColor
Get color value from Copper by supplying a parameter 0.0 <= h <= 1.0
Sourcepub fn get_color_normalized<FloatType>(
h: FloatType,
min: FloatType,
max: FloatType,
) -> RGBColor
pub fn get_color_normalized<FloatType>( h: FloatType, min: FloatType, max: FloatType, ) -> RGBColor
Get color value from Copper by supplying lower and upper bounds min, max and a parameter h where min <= h <= max