pub struct MandelbrotHSL;Expand description
Colormap created to replace the one used in the mandelbrot example.
Implementations
Sourceimpl MandelbrotHSL
impl MandelbrotHSL
Sourcepub fn get_color<FloatType>(h: FloatType) -> HSLColor
pub fn get_color<FloatType>(h: FloatType) -> HSLColor
Get color value from MandelbrotHSL by supplying a parameter 0.0 <= h <= 1.0
Sourcepub fn get_color_normalized<FloatType>(
h: FloatType,
min: FloatType,
max: FloatType,
) -> HSLColor
pub fn get_color_normalized<FloatType>( h: FloatType, min: FloatType, max: FloatType, ) -> HSLColor
Get color value from MandelbrotHSL by supplying lower and upper bounds min, max and a parameter h where min <= h <= max