pub trait AsRelative: Into<f64> {
// Provided methods
fn percent_width(self) -> RelativeSize { ... }
fn percent_height(self) -> RelativeSize { ... }
fn percent(self) -> RelativeSize { ... }
}Expand description
Allows a value turns into a relative size
Provided Methods
Sourcefn percent_width(self) -> RelativeSize
fn percent_width(self) -> RelativeSize
Make the value a relative size of percentage of width
Sourcefn percent_height(self) -> RelativeSize
fn percent_height(self) -> RelativeSize
Make the value a relative size of percentage of height
Sourcefn percent(self) -> RelativeSize
fn percent(self) -> RelativeSize
Make the value a relative size of percentage of minimal of height and width
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".